/*
 * gDMM Digital Multimeter Application
 *
 * File: configdialog.c
 *
 * Copyright (c) 2003-2004 Johannes Heimansberg
 *
 * gDMM is a GTK+ 2 based application which reads data from a Digital Multimeter
 * (Metex/Voltcraft or compatible, e.g. M-3650D) through the serial interface
 * (RS-232) and draws a graph out of this data. Measurements can also be 
 * saved to/loaded from disk.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <gtk/gtk.h>
#include <glib.h>
#include "wejpconfig.h"
#include "configdialog.h"

/* Save settings function */
void save_settings(SettingsDialog *sd)
{
	char buffer[128] = "";
	sprintf(buffer, "%d", gtk_combo_box_get_active(GTK_COMBO_BOX(sd->combo)));

	cfg_add_key(&(sd->cf), "DMMModel", 
	            buffer);
	cfg_add_key(&(sd->cf), "Port",
	            (char*)gtk_entry_get_text(GTK_ENTRY(sd->textfield)));

	gtk_widget_destroy(sd->dialog); /* Destroy the dialog */
	sd->dialog = NULL;

	cfg_write_config_file(&(sd->cf), cfg_get_path_to_config_file(".gdmmrc"));
}

/* Creates a tree model containing the completions */
GtkTreeModel * create_completion_model(void)
{
	GtkListStore *store;
	GtkTreeIter iter;

	store = gtk_list_store_new(1, G_TYPE_STRING);

	/* Append one word */
	gtk_list_store_append(store, &iter);
	gtk_list_store_set(store, &iter, 0, "/dev/ttyS0", -1);

	/* Append another word */
	gtk_list_store_append(store, &iter);
	gtk_list_store_set(store, &iter, 0, "/dev/ttyS1", -1);

	/* And another word */
	gtk_list_store_append(store, &iter);
	gtk_list_store_set(store, &iter, 0, "/dev/ttyS2", -1);

	/* And another word */
	gtk_list_store_append(store, &iter);
	gtk_list_store_set(store, &iter, 0, "/dev/ttyS3", -1);

	return GTK_TREE_MODEL(store);
}

void config_dialog_show(SettingsDialog *sd)
{
	gint response;

	cfg_init_config_file_struct(&(sd->cf));
	cfg_read_config_file(&(sd->cf), cfg_get_path_to_config_file(".gdmmrc"));
	
	if (sd->dialog == NULL)
	{
		sd->dialog = gtk_dialog_new_with_buttons("gDMM Configuration",
					GTK_WINDOW(sd->parent),
					GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
		            GTK_STOCK_CANCEL,
                    GTK_RESPONSE_CANCEL,
					GTK_STOCK_OK,
					GTK_RESPONSE_OK,
					NULL);

		sd->hbox = gtk_hbox_new(FALSE, 3);
		gtk_container_set_border_width(GTK_CONTAINER(sd->hbox), 8);
		gtk_box_pack_start(GTK_BOX(GTK_DIALOG(sd->dialog)->vbox),
		                   sd->hbox, FALSE, FALSE, 0);
		
		sd->table = gtk_table_new(2, 2, FALSE);
		gtk_table_set_row_spacings(GTK_TABLE(sd->table), 4);
		gtk_table_set_col_spacings(GTK_TABLE(sd->table), 4);
		gtk_box_pack_start(GTK_BOX(sd->hbox), sd->table, TRUE, TRUE, 0);

		sd->label1 = gtk_label_new("DMM Model:");
		
		gtk_table_attach_defaults(GTK_TABLE (sd->table),
			                      sd->label1,
			                      0, 1, 0, 1);

		/* Combo list with DMMs to select: */
		sd->combo = gtk_combo_box_new_text();

		gtk_combo_box_append_text(GTK_COMBO_BOX(sd->combo), "Metex_M-3xxxD");
		gtk_combo_box_append_text(GTK_COMBO_BOX(sd->combo), "Other_DMM");

		gtk_combo_box_set_active(GTK_COMBO_BOX(sd->combo), 0);

		gtk_table_attach_defaults (GTK_TABLE(sd->table), sd->combo, 1, 2, 0, 1);

		sd->label2 = gtk_label_new("Connected to:");
		gtk_table_attach_defaults(GTK_TABLE(sd->table), sd->label2, 0, 1, 1, 2);

		/* Entry for the serial device: */
		sd->textfield = gtk_entry_new();
		gtk_entry_set_text(GTK_ENTRY(sd->textfield),
		                   cfg_get_key_value(sd->cf, "Port"));
		gtk_table_attach_defaults(GTK_TABLE(sd->table), sd->textfield, 1, 2, 1, 2);

		sd->completion = gtk_entry_completion_new();
		gtk_entry_set_completion(GTK_ENTRY(sd->textfield), sd->completion);
		g_object_unref(sd->completion);
		
		sd->completion_model = create_completion_model();
		gtk_entry_completion_set_model(sd->completion, sd->completion_model);
		g_object_unref(sd->completion_model);

		gtk_entry_completion_set_text_column(sd->completion, 0);


		gtk_widget_show_all(sd->hbox);

		/* Run the dialog: */
		response = gtk_dialog_run(GTK_DIALOG(sd->dialog));
		if (response == GTK_RESPONSE_OK) /* Ok button */
		{
			save_settings(sd);
		}
		else /* Cancel button or close via menu */
		{
			gtk_widget_destroy(sd->dialog);
			sd->dialog = NULL;
		}
	}
}
