/*
 * gDMM Digital Multimeter Application
 *
 * File: dmmread.h
 *
 * Copyright (c) 2003 Johannes Heimansberg
 *
 * gDMM is a GTK+ 2 based application which reads data from a Digital Multimeter
 * (Metex/Voltcraft or compatible, e.g. M-3650D) through the serial interface
 * (RS-232) and draws a graph out of this data. Measurements can also be 
 * saved to/loaded from disk.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef _DMMREAD_h
#define _DMMREAD_H
typedef struct
{
	double value;       /* Measured value as float  */
	double value_max;   /* Maximum and */
	double value_min;   /* minimum value */

	char   unit[32];    /* Unit of the measurement */
	int    unit_changed;/* TRUE if unit changed during measurement */
	char   rawdata[32]; /* Rawdata read from DMM */

	char   *dmm_model;  /* String with the DMM model name */

	char   *rawdata_array[23000];
	int    value_array_counter;
} DMM;
#endif

int    dmm_open_port(char* serialDevice, int baudRate, int dataBits, int stopBits);
void   dmm_read(int fd, DMM *dmm);
double dmm_decode_string_m3650(DMM *dmm, int number);
void   dmm_init_struct(DMM *dmm);
void   dmm_clear_struct(DMM *dmm);
int    dmm_save_measurement_to_file(DMM *dmm, char *filename);
int    dmm_load_measurement_from_file(DMM *dmm, char *filename);

double dmm_get_last_value(DMM *dmm);
double dmm_get_max_value(DMM *dmm);
double dmm_get_min_value(DMM *dmm);
int    dmm_get_number_of_stored_values(DMM *dmm);
double dmm_get_stored_value(DMM *dmm, int number);
char*  dmm_get_rawdata(DMM *dmm);
char*  dmm_get_unit(DMM *dmm);
int    dmm_is_unit_changed(DMM *dmm);

void   dmm_print_all_rawdata(DMM *dmm);
