/*
 * gDMM Digital Multimeter Application
 *
 * File: graphwidget.h
 *
 * Copyright (c) 2003-2004 Johannes Heimansberg
 *
 * gDMM is a GTK+ 2 based application which reads data from a Digital Multimeter
 * (Metex/Voltcraft or compatible, e.g. M-3650D) through the serial interface
 * (RS-232) and draws a graph out of this data. Measurements can also be 
 * saved to/loaded from disk.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef _GRAPHWIDGET_h
#define _GRAPHWIDGET_H
typedef struct
{
	GtkWidget     *frame;        /* Border around the drawing area (3d style) */
	GtkWidget     *drawing_area;
	GtkPixmap     *pixmap;
	GtkAdjustment *adjustment;
	GtkWidget     *scrollbar;
	GtkWidget     *box;          /* Contains the other widgets */
	GdkColormap   *colormap;
	PangoLayout   *pgl;
	int           zoom;          /* Zoom */
	int           ZOOM_DEFAULT;
	DMM           dmm;           /* Struct with the DMM data */
} GraphWidget;
#endif


gboolean  graph_configure_event_callback(GtkWidget *widget, GdkEventConfigure *event, GraphWidget *gwt);
gboolean  graph_expose_event_callback(GtkWidget *widget, GdkEventExpose *event, GraphWidget *gwt);
void      graph_scrollbar_moved_callback(GtkAdjustment *adjustment, GraphWidget *gwt);

void      graph_draw(GraphWidget *gwt);
void      graph_zoom_in(GraphWidget *gw);
void      graph_zoom_out(GraphWidget *gw);
void      graph_zoom_default(GraphWidget *gw);
void      graph_update_adjustment(GraphWidget *gwt);
GtkWidget *graph_widget_create(GraphWidget *gw);
